from distutils.core import setup
setup(
    name = "zequals",
    packages = ["zequals"],
    version = "0.0.3",
	description = "Ruthless Rounding at it's Finest :)",
    author = "Henri Kuiper",
    author_email = "henrikuiper@zdevops.com",
	url = "http://www.youtube.com/watch?v=aOJOfh2_4PE",
    download_url = "",
    keywords = ["numberphile", "Rob Eastaway", "zequalize"],
    classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "Environment :: Other Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        ],
)
